@@ -172,7 +172,7 @@ set( 'DOCHAZKA_LDAP_AUTOCREATE', 0 );
 
 # DOCHAZKA_LDAP_AUTOCREATE_AS
 #     Priv level to assign to LDAP-autocreated users
-set( 'DOCHAZKA_LDAP_AUTOCREATE_AS', 'active' );
+set( 'DOCHAZKA_LDAP_AUTOCREATE_AS', 'passerby' );
 
 # DOCHAZKA_LDAP_SERVER
 #     LDAP server for LDAP authentication
